@@ -30,18 +30,28 @@ Submodules
     warnings
     dynamics
 
+Inheritance
+-------------
+.. inheritance-diagram:: pwspy.analysis.pws.PWSAnalysisSettings pwspy.analysis.pws.PWSAnalysisResults pwspy.analysis.pws.PWSAnalysis pwspy.analysis.dynamics.DynamicsAnalysisSettings pwspy.analysis.dynamics.DynamicsAnalysisResults pwspy.analysis.dynamics.DynamicsAnalysis
+    :parts: 1
+
 """
 import os
 from ._abstract import AbstractAnalysisSettings, AbstractAnalysis, AbstractAnalysisResults, AbstractHDFAnalysisResults
 from . import pws
 from . import dynamics
 from . import compilation
+from ._utility import ParallelRunner
 # TODO settings are missing reference IDtag but they exist in the results. Results and settings both contain extra reflectance idTag, reduntant
 
 resources = os.path.join(os.path.split(__file__)[0], '_resources')
 defaultSettingsPath = os.path.join(resources, 'defaultAnalysisSettings')
 
 __all__ = ['AbstractAnalysisSettings', 'AbstractAnalysis', 'AbstractAnalysisResults',
-           'AbstractHDFAnalysisResults', 'resources', 'defaultSettingsPath', 'pws', 'dynamics', 'compilation']
+           'AbstractHDFAnalysisResults', 'resources', 'defaultSettingsPath', 'pws', 'dynamics', 'compilation', 'ParallelRunner']
+
+
+
+
 
 
